@@ -1,49 +1,56 @@
 ;;; GnuTLS-extra --- Guile bindings for GnuTLS-EXTRA.
 ;;; Copyright (C) 2007-2023 Free Software Foundation, Inc.
 ;;;
-;;; GnuTLS-extra is free software; you can redistribute it and/or modify
+;;; This file is part of Guile-GnuTLS.
+;;;
+;;; This program is free software: you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 3 of the License, or
+;;; the Free Software Foundation, either version 3 of the License, or
 ;;; (at your option) any later version.
 ;;;
-;;; GnuTLS-extra is distributed in the hope that it will be useful,
+;;; This program is distributed in the hope that it will be useful,
 ;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;;; GNU General Public License for more details.
 ;;;
 ;;; You should have received a copy of the GNU General Public License
-;;; along with GnuTLS-EXTRA; if not, write to the Free Software
-;;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-;;; USA.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-;;; Written by Ludovic Courts <ludo@gnu.org>
+;;; Written by Ludovic Courtès <ludo@gnu.org>
 
 (define-module (gnutls extra)
 
   :use-module (gnutls)
 
   :re-export (;; OpenPGP keys
-           openpgp-certificate? openpgp-private-key?
-           import-openpgp-certificate import-openpgp-private-key
-           openpgp-certificate-id openpgp-certificate-id!
-           openpgp-certificate-fingerprint openpgp-certificate-fingerprint!
-           openpgp-certificate-name openpgp-certificate-names
-           openpgp-certificate-algorithm openpgp-certificate-version
-           openpgp-certificate-usage
+              openpgp-certificate?
+              openpgp-private-key?
+              import-openpgp-certificate
+              import-openpgp-private-key
+              openpgp-certificate-id
+              openpgp-certificate-id!
+              openpgp-certificate-fingerprint
+              openpgp-certificate-fingerprint!
+              openpgp-certificate-name
+              openpgp-certificate-names
+              openpgp-certificate-algorithm
+              openpgp-certificate-version
+              openpgp-certificate-usage
 
-           ;; OpenPGP keyrings
-           openpgp-keyring? import-openpgp-keyring
-           openpgp-keyring-contains-key-id?
+              ;; OpenPGP keyrings
+              openpgp-keyring?
+              import-openpgp-keyring
+              openpgp-keyring-contains-key-id?
 
-           ;; certificate credentials
-           set-certificate-credentials-openpgp-keys!
+              ;; certificate credentials
+              set-certificate-credentials-openpgp-keys!
 
-           ;; enum->string functions
-           openpgp-certificate-format->string
+              ;; enum->string functions
+              openpgp-certificate-format->string
 
-           ;; enum values
-           openpgp-certificate-format/raw
-           openpgp-certificate-format/base64))
+              ;; enum values
+              openpgp-certificate-format/raw
+              openpgp-certificate-format/base64))
 
 
 
@@ -79,5 +86,5 @@
 
 ;;; Local Variables:
 ;;; mode: scheme
-;;; coding: latin-1
+;;; coding: utf-8
 ;;; End:
