@@ -1,19 +1,20 @@
 /* GnuTLS --- Guile bindings for GnuTLS.
    Copyright (C) 2007-2023 Free Software Foundation, Inc.
 
-   GnuTLS is free software; you can redistribute it and/or
+   This file is part of Guile-GnuTLS.
+
+   This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.
 
-   GnuTLS is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with GnuTLS; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this library; if not, see <https://www.gnu.org/licenses/>. */
 
 #ifndef GUILE_GNUTLS_UTILS_H
 # define GUILE_GNUTLS_UTILS_H
@@ -44,7 +45,7 @@ extern const char scm_gnutls_array_error_message[];
 /* Initialize C_HANDLE and C_LEN and return the contiguous C array
    corresponding to ARRAY.  */
 static inline const char *
-scm_gnutls_get_array (SCM array, scm_t_array_handle * c_handle,
+scm_gnutls_get_array (SCM array, scm_t_array_handle *c_handle,
 		      size_t *c_len, const char *func_name)
 {
   const char *c_array = NULL;
@@ -74,7 +75,7 @@ scm_gnutls_get_array (SCM array, scm_t_array_handle * c_handle,
 /* Initialize C_HANDLE and C_LEN and return the contiguous C array
    corresponding to ARRAY.  The returned array can be written to.  */
 static inline char *
-scm_gnutls_get_writable_array (SCM array, scm_t_array_handle * c_handle,
+scm_gnutls_get_writable_array (SCM array, scm_t_array_handle *c_handle,
 			       size_t *c_len, const char *func_name)
 {
   char *c_array = NULL;
@@ -113,7 +114,7 @@ do_scm_gnutls_release_array (void *arg)
 
 /* Release an array handle at the end of a dynwind section. */
 static inline void
-scm_dynwind_release_handle (scm_t_array_handle * handle)
+scm_dynwind_release_handle (scm_t_array_handle *handle)
 {
   scm_dynwind_unwind_handler (do_scm_gnutls_release_array, handle,
 			      SCM_F_WIND_EXPLICITLY);
